@@ -2,18 +2,18 @@ from enum import Enum
 
 
 class LogicalOperator(Enum):
-    OR = "OR",
+    OR = "OR"
     AND = "AND"
 
 
 class CalculationOperator(Enum):
-    EQUAL = "=",
-    NOTEQUAL = "!=",
-    GT = ">",
-    GTE = ">=",
-    LT = "<",
-    LTE = "<=",
-    IN = "in",
+    EQUAL = "="
+    NOTEQUAL = "!="
+    GT = ">"
+    GTE = ">="
+    LT = "<"
+    LTE = "<="
+    IN = "in"
     LIKE = "like"
 
 
