@@ -22,9 +22,9 @@ def on_request(self, protocol):
     log.info(f"从celery中获取到任务:{protocol}")
     try:
         # 子进程中也开启eureka_client的刷新,因为celery也会起子进程,所以只能在这里初始化了
-        from py_eureka_client import eureka_client
+        from discovery import discovery_service_proxy
         import config
-        eureka_client.init_discovery_client(eureka_server=config.eureka_default_zone, renewal_interval_in_secs=4)
+        discovery_service_proxy().registry_discovery(config.eureka_default_zone, renewal_interval_in_secs=4)
     except:
         pass
 
