@@ -1,15 +1,16 @@
 import logging
 import sys
-# 开始使用异步服务器启动 TODO 发现异步在message消息的情况下会异常退出,先不使用
-# import gevent.monkey
-# gevent.monkey.patch_all()
 
 from flask import Flask
 from flask_cors import *
-from munch import Munch
 
 import config
 from config import annotation
+from discovery import discovery_service_proxy
+
+# 开始使用异步服务器启动 TODO 发现异步在message消息的情况下会异常退出,先不使用
+# import gevent.monkey
+# gevent.monkey.patch_all()
 
 log = logging.getLogger('Ficus')
 
@@ -33,20 +34,16 @@ init_from_environ_property()
 
 log.info("服务启动,完成本地yaml配置文件读取")
 
-# 注册信息到eureka中
-from py_eureka_client import eureka_client
-
-eureka_client.init(eureka_server=config.eureka_default_zone,
-                   app_name=config.application_name,
-                   # 当前组件的主机名，可选参数，如果不填写会自动计算一个，如果服务和 eureka 服务器部署在同一台机器，请必须填写，否则会计算出 127.0.0.1
-                   instance_host=config.server_ip or config.find_host_ip(),
-                   instance_port=config.server_port or 5000,
-                   # 调用其他服务时的高可用策略，可选，默认为随机
-                   ha_strategy=eureka_client.HA_STRATEGY_STICK,
-                   status_page_url="/actuator/info",
-                   health_check_url="/actuator/health",
-                   renewal_interval_in_secs=4,
-                   duration_in_secs=12)
+# 注册信息到注册中心中
+discovery_service_proxy().registry(server=config.eureka_default_zone,
+                                   app_name=config.application_name,
+                                   # 当前组件的主机名，可选参数，如果不填写会自动计算一个，如果服务和 eureka 服务器部署在同一台机器，请必须填写，否则会计算出 127.0.0.1
+                                   instance_host=config.server_ip or config.find_host_ip(),
+                                   instance_port=config.server_port or 5000,
+                                   status_page_url="/actuator/info",
+                                   health_check_url="/actuator/health",
+                                   renewal_interval_in_secs=4,
+                                   duration_in_secs=12)
 
 log.info("服务启动,完成注册中心注册及心跳")
 
@@ -94,12 +91,11 @@ except Exception as e:
 log.info("服务启动,完成处理器的预加载")
 
 # 程序启动后,判断是否需要注册执行器
-from registry import LoadOnRegistryLoader,LoadOnAlgorithmLoader
+from registry import LoadOnRegistryLoader, LoadOnAlgorithmLoader
 
 LoadOnRegistryLoader.registry_after_started()
 LoadOnAlgorithmLoader.registry_after_started()
 
-
 log.info("服务启动,完成处理器的注册")
 
 from schedule.utils.log.TaskLogCleanScheduler import TaskLogCleanScheduler
